@@ -4,16 +4,14 @@ Main interface for workspaces-web service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_workspaces_web import (
         Client,
         WorkSpacesWebClient,
     )
 
-    session = boto3.Session()
-
-    client: WorkSpacesWebClient = boto3.client("workspaces-web")
-    session_client: WorkSpacesWebClient = session.client("workspaces-web")
+    session = Session()
+    client: WorkSpacesWebClient = session.client("workspaces-web")
     ```
 """
 from .client import WorkSpacesWebClient
